@@ -62,13 +62,10 @@ class ProductDetailView(DetailView):
 def sendAnEmail(request):
 
     if request.method == 'POST': # If the form has been submitted...
-
-        print request.POST
         texto = "<ul>"
         for i in request.POST:
             texto = texto + "<li>" + i +": "+ request.POST[i] + "</li>"
         texto = texto + "</ul>"
-        #return HttpResponse(texto, content_type="text/plain")
     email = EmailMessage(_('New order!'), texto, to=[conf.SITE_CONTACT_EMAIL])
     email.content_subtype = "html"  # Main content is now text/html
     email.send()
